Timev

Enum Timev 

pub enum Timev {
    NoTimevent = 0,
    Timevent = 1,
}
Time Event

Value on reset: 0

Variants



NoTimevent = 0

0: No time event has occurred since the last clear.



Timevent = 1

1: At least one time event has occurred since the last clear.